@@ -52,6 +52,7 @@ class TargetPoolsRestTransport(TargetPoolsTransport):
         client_cert_source_for_mtls: Callable[[], Tuple[bytes, bytes]] = None,
         quota_project_id: Optional[str] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
+        always_use_jwt_access: Optional[bool] = False,
     ) -> None:
         """Instantiate the transport.
 
@@ -85,7 +86,10 @@ class TargetPoolsRestTransport(TargetPoolsTransport):
         # TODO: When custom host (api_endpoint) is set, `scopes` must *also* be set on the
         # credentials object
         super().__init__(
-            host=host, credentials=credentials, client_info=client_info,
+            host=host,
+            credentials=credentials,
+            client_info=client_info,
+            always_use_jwt_access=always_use_jwt_access,
         )
         self._session = AuthorizedSession(
             self._credentials, default_host=self.DEFAULT_HOST
@@ -166,16 +170,12 @@ class TargetPoolsRestTransport(TargetPoolsTransport):
         if compute.AddHealthCheckTargetPoolRequest.request_id in request:
             query_params["requestId"] = request.request_id
 
-        # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
-        #               discards default values
-        # TODO(yon-mg): add test for proper url encoded strings
-        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
-        url += "?{}".format("&".join(query_params)).replace(" ", "+")
-
         # Send the request
         headers = dict(metadata)
         headers["Content-Type"] = "application/json"
-        response = self._session.post(url, headers=headers, data=body,)
+        response = self._session.post(
+            url, headers=headers, params=query_params, data=body,
+        )
 
         # In case of error, raise the appropriate core_exceptions.GoogleAPICallError exception
         # subclass.
@@ -257,16 +257,12 @@ class TargetPoolsRestTransport(TargetPoolsTransport):
         if compute.AddInstanceTargetPoolRequest.request_id in request:
             query_params["requestId"] = request.request_id
 
-        # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
-        #               discards default values
-        # TODO(yon-mg): add test for proper url encoded strings
-        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
-        url += "?{}".format("&".join(query_params)).replace(" ", "+")
-
         # Send the request
         headers = dict(metadata)
         headers["Content-Type"] = "application/json"
-        response = self._session.post(url, headers=headers, data=body,)
+        response = self._session.post(
+            url, headers=headers, params=query_params, data=body,
+        )
 
         # In case of error, raise the appropriate core_exceptions.GoogleAPICallError exception
         # subclass.
@@ -320,16 +316,10 @@ class TargetPoolsRestTransport(TargetPoolsTransport):
         if compute.AggregatedListTargetPoolsRequest.return_partial_success in request:
             query_params["returnPartialSuccess"] = request.return_partial_success
 
-        # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
-        #               discards default values
-        # TODO(yon-mg): add test for proper url encoded strings
-        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
-        url += "?{}".format("&".join(query_params)).replace(" ", "+")
-
         # Send the request
         headers = dict(metadata)
         headers["Content-Type"] = "application/json"
-        response = self._session.get(url, headers=headers,)
+        response = self._session.get(url, headers=headers, params=query_params,)
 
         # In case of error, raise the appropriate core_exceptions.GoogleAPICallError exception
         # subclass.
@@ -406,16 +396,10 @@ class TargetPoolsRestTransport(TargetPoolsTransport):
         if compute.DeleteTargetPoolRequest.request_id in request:
             query_params["requestId"] = request.request_id
 
-        # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
-        #               discards default values
-        # TODO(yon-mg): add test for proper url encoded strings
-        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
-        url += "?{}".format("&".join(query_params)).replace(" ", "+")
-
         # Send the request
         headers = dict(metadata)
         headers["Content-Type"] = "application/json"
-        response = self._session.delete(url, headers=headers,)
+        response = self._session.delete(url, headers=headers, params=query_params,)
 
         # In case of error, raise the appropriate core_exceptions.GoogleAPICallError exception
         # subclass.
@@ -468,16 +452,10 @@ class TargetPoolsRestTransport(TargetPoolsTransport):
         #               not required for GCE
         query_params = {}
 
-        # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
-        #               discards default values
-        # TODO(yon-mg): add test for proper url encoded strings
-        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
-        url += "?{}".format("&".join(query_params)).replace(" ", "+")
-
         # Send the request
         headers = dict(metadata)
         headers["Content-Type"] = "application/json"
-        response = self._session.get(url, headers=headers,)
+        response = self._session.get(url, headers=headers, params=query_params,)
 
         # In case of error, raise the appropriate core_exceptions.GoogleAPICallError exception
         # subclass.
@@ -531,16 +509,12 @@ class TargetPoolsRestTransport(TargetPoolsTransport):
         #               not required for GCE
         query_params = {}
 
-        # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
-        #               discards default values
-        # TODO(yon-mg): add test for proper url encoded strings
-        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
-        url += "?{}".format("&".join(query_params)).replace(" ", "+")
-
         # Send the request
         headers = dict(metadata)
         headers["Content-Type"] = "application/json"
-        response = self._session.post(url, headers=headers, data=body,)
+        response = self._session.post(
+            url, headers=headers, params=query_params, data=body,
+        )
 
         # In case of error, raise the appropriate core_exceptions.GoogleAPICallError exception
         # subclass.
@@ -621,16 +595,12 @@ class TargetPoolsRestTransport(TargetPoolsTransport):
         if compute.InsertTargetPoolRequest.request_id in request:
             query_params["requestId"] = request.request_id
 
-        # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
-        #               discards default values
-        # TODO(yon-mg): add test for proper url encoded strings
-        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
-        url += "?{}".format("&".join(query_params)).replace(" ", "+")
-
         # Send the request
         headers = dict(metadata)
         headers["Content-Type"] = "application/json"
-        response = self._session.post(url, headers=headers, data=body,)
+        response = self._session.post(
+            url, headers=headers, params=query_params, data=body,
+        )
 
         # In case of error, raise the appropriate core_exceptions.GoogleAPICallError exception
         # subclass.
@@ -684,16 +654,10 @@ class TargetPoolsRestTransport(TargetPoolsTransport):
         if compute.ListTargetPoolsRequest.return_partial_success in request:
             query_params["returnPartialSuccess"] = request.return_partial_success
 
-        # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
-        #               discards default values
-        # TODO(yon-mg): add test for proper url encoded strings
-        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
-        url += "?{}".format("&".join(query_params)).replace(" ", "+")
-
         # Send the request
         headers = dict(metadata)
         headers["Content-Type"] = "application/json"
-        response = self._session.get(url, headers=headers,)
+        response = self._session.get(url, headers=headers, params=query_params,)
 
         # In case of error, raise the appropriate core_exceptions.GoogleAPICallError exception
         # subclass.
@@ -777,16 +741,12 @@ class TargetPoolsRestTransport(TargetPoolsTransport):
         if compute.RemoveHealthCheckTargetPoolRequest.request_id in request:
             query_params["requestId"] = request.request_id
 
-        # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
-        #               discards default values
-        # TODO(yon-mg): add test for proper url encoded strings
-        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
-        url += "?{}".format("&".join(query_params)).replace(" ", "+")
-
         # Send the request
         headers = dict(metadata)
         headers["Content-Type"] = "application/json"
-        response = self._session.post(url, headers=headers, data=body,)
+        response = self._session.post(
+            url, headers=headers, params=query_params, data=body,
+        )
 
         # In case of error, raise the appropriate core_exceptions.GoogleAPICallError exception
         # subclass.
@@ -868,16 +828,12 @@ class TargetPoolsRestTransport(TargetPoolsTransport):
         if compute.RemoveInstanceTargetPoolRequest.request_id in request:
             query_params["requestId"] = request.request_id
 
-        # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
-        #               discards default values
-        # TODO(yon-mg): add test for proper url encoded strings
-        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
-        url += "?{}".format("&".join(query_params)).replace(" ", "+")
-
         # Send the request
         headers = dict(metadata)
         headers["Content-Type"] = "application/json"
-        response = self._session.post(url, headers=headers, data=body,)
+        response = self._session.post(
+            url, headers=headers, params=query_params, data=body,
+        )
 
         # In case of error, raise the appropriate core_exceptions.GoogleAPICallError exception
         # subclass.
@@ -961,16 +917,12 @@ class TargetPoolsRestTransport(TargetPoolsTransport):
         if compute.SetBackupTargetPoolRequest.request_id in request:
             query_params["requestId"] = request.request_id
 
-        # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
-        #               discards default values
-        # TODO(yon-mg): add test for proper url encoded strings
-        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
-        url += "?{}".format("&".join(query_params)).replace(" ", "+")
-
         # Send the request
         headers = dict(metadata)
         headers["Content-Type"] = "application/json"
-        response = self._session.post(url, headers=headers, data=body,)
+        response = self._session.post(
+            url, headers=headers, params=query_params, data=body,
+        )
 
         # In case of error, raise the appropriate core_exceptions.GoogleAPICallError exception
         # subclass.
