@@ -111,6 +111,25 @@ def test_routers_client_from_service_account_info(client_class):
         assert client.transport._host == "compute.googleapis.com:443"
 
 
+@pytest.mark.parametrize(
+    "transport_class,transport_name", [(transports.RoutersRestTransport, "rest"),]
+)
+def test_routers_client_service_account_always_use_jwt(transport_class, transport_name):
+    with mock.patch.object(
+        service_account.Credentials, "with_always_use_jwt_access", create=True
+    ) as use_jwt:
+        creds = service_account.Credentials(None, None, None)
+        transport = transport_class(credentials=creds, always_use_jwt_access=True)
+        use_jwt.assert_called_once_with(True)
+
+    with mock.patch.object(
+        service_account.Credentials, "with_always_use_jwt_access", create=True
+    ) as use_jwt:
+        creds = service_account.Credentials(None, None, None)
+        transport = transport_class(credentials=creds, always_use_jwt_access=False)
+        use_jwt.assert_not_called()
+
+
 @pytest.mark.parametrize("client_class", [RoutersClient,])
 def test_routers_client_from_service_account_file(client_class):
     creds = ga_credentials.AnonymousCredentials()
@@ -473,7 +492,8 @@ def test_aggregated_list_rest_flattened():
         assert len(req.mock_calls) == 1
         _, http_call, http_params = req.mock_calls[0]
         body = http_params.get("data")
-        assert "project_value" in http_call[1] + str(body)
+        params = http_params.get("params")
+        assert "project_value" in http_call[1] + str(body) + str(params)
 
 
 def test_aggregated_list_rest_flattened_error():
@@ -567,7 +587,7 @@ def test_delete_rest(transport: str = "rest", request_type=compute.DeleteRouterR
             error=compute.Error(errors=[compute.Errors(code="code_value")]),
             http_error_message="http_error_message_value",
             http_error_status_code=2374,
-            id="id_value",
+            id=205,
             insert_time="insert_time_value",
             kind="kind_value",
             name="name_value",
@@ -579,7 +599,7 @@ def test_delete_rest(transport: str = "rest", request_type=compute.DeleteRouterR
             start_time="start_time_value",
             status=compute.Operation.Status.DONE,
             status_message="status_message_value",
-            target_id="target_id_value",
+            target_id=947,
             target_link="target_link_value",
             user="user_value",
             warnings=[compute.Warnings(code=compute.Warnings.Code.CLEANUP_FAILED)],
@@ -603,7 +623,7 @@ def test_delete_rest(transport: str = "rest", request_type=compute.DeleteRouterR
     assert response.error == compute.Error(errors=[compute.Errors(code="code_value")])
     assert response.http_error_message == "http_error_message_value"
     assert response.http_error_status_code == 2374
-    assert response.id == "id_value"
+    assert response.id == 205
     assert response.insert_time == "insert_time_value"
     assert response.kind == "kind_value"
     assert response.name == "name_value"
@@ -615,7 +635,7 @@ def test_delete_rest(transport: str = "rest", request_type=compute.DeleteRouterR
     assert response.start_time == "start_time_value"
     assert response.status == compute.Operation.Status.DONE
     assert response.status_message == "status_message_value"
-    assert response.target_id == "target_id_value"
+    assert response.target_id == 947
     assert response.target_link == "target_link_value"
     assert response.user == "user_value"
     assert response.warnings == [
@@ -654,9 +674,10 @@ def test_delete_rest_flattened():
         assert len(req.mock_calls) == 1
         _, http_call, http_params = req.mock_calls[0]
         body = http_params.get("data")
-        assert "project_value" in http_call[1] + str(body)
-        assert "region_value" in http_call[1] + str(body)
-        assert "router_value" in http_call[1] + str(body)
+        params = http_params.get("params")
+        assert "project_value" in http_call[1] + str(body) + str(params)
+        assert "region_value" in http_call[1] + str(body) + str(params)
+        assert "router_value" in http_call[1] + str(body) + str(params)
 
 
 def test_delete_rest_flattened_error():
@@ -697,7 +718,7 @@ def test_get_rest(transport: str = "rest", request_type=compute.GetRouterRequest
             creation_timestamp="creation_timestamp_value",
             description="description_value",
             encrypted_interconnect_router=True,
-            id="id_value",
+            id=205,
             interfaces=[compute.RouterInterface(ip_range="ip_range_value")],
             kind="kind_value",
             name="name_value",
@@ -726,7 +747,7 @@ def test_get_rest(transport: str = "rest", request_type=compute.GetRouterRequest
     assert response.creation_timestamp == "creation_timestamp_value"
     assert response.description == "description_value"
     assert response.encrypted_interconnect_router is True
-    assert response.id == "id_value"
+    assert response.id == 205
     assert response.interfaces == [compute.RouterInterface(ip_range="ip_range_value")]
     assert response.kind == "kind_value"
     assert response.name == "name_value"
@@ -766,9 +787,10 @@ def test_get_rest_flattened():
         assert len(req.mock_calls) == 1
         _, http_call, http_params = req.mock_calls[0]
         body = http_params.get("data")
-        assert "project_value" in http_call[1] + str(body)
-        assert "region_value" in http_call[1] + str(body)
-        assert "router_value" in http_call[1] + str(body)
+        params = http_params.get("params")
+        assert "project_value" in http_call[1] + str(body) + str(params)
+        assert "region_value" in http_call[1] + str(body) + str(params)
+        assert "router_value" in http_call[1] + str(body) + str(params)
 
 
 def test_get_rest_flattened_error():
@@ -858,9 +880,10 @@ def test_get_nat_mapping_info_rest_flattened():
         assert len(req.mock_calls) == 1
         _, http_call, http_params = req.mock_calls[0]
         body = http_params.get("data")
-        assert "project_value" in http_call[1] + str(body)
-        assert "region_value" in http_call[1] + str(body)
-        assert "router_value" in http_call[1] + str(body)
+        params = http_params.get("params")
+        assert "project_value" in http_call[1] + str(body) + str(params)
+        assert "region_value" in http_call[1] + str(body) + str(params)
+        assert "router_value" in http_call[1] + str(body) + str(params)
 
 
 def test_get_nat_mapping_info_rest_flattened_error():
@@ -997,9 +1020,10 @@ def test_get_router_status_rest_flattened():
         assert len(req.mock_calls) == 1
         _, http_call, http_params = req.mock_calls[0]
         body = http_params.get("data")
-        assert "project_value" in http_call[1] + str(body)
-        assert "region_value" in http_call[1] + str(body)
-        assert "router_value" in http_call[1] + str(body)
+        params = http_params.get("params")
+        assert "project_value" in http_call[1] + str(body) + str(params)
+        assert "region_value" in http_call[1] + str(body) + str(params)
+        assert "router_value" in http_call[1] + str(body) + str(params)
 
 
 def test_get_router_status_rest_flattened_error():
@@ -1036,7 +1060,7 @@ def test_insert_rest(transport: str = "rest", request_type=compute.InsertRouterR
             error=compute.Error(errors=[compute.Errors(code="code_value")]),
             http_error_message="http_error_message_value",
             http_error_status_code=2374,
-            id="id_value",
+            id=205,
             insert_time="insert_time_value",
             kind="kind_value",
             name="name_value",
@@ -1048,7 +1072,7 @@ def test_insert_rest(transport: str = "rest", request_type=compute.InsertRouterR
             start_time="start_time_value",
             status=compute.Operation.Status.DONE,
             status_message="status_message_value",
-            target_id="target_id_value",
+            target_id=947,
             target_link="target_link_value",
             user="user_value",
             warnings=[compute.Warnings(code=compute.Warnings.Code.CLEANUP_FAILED)],
@@ -1072,7 +1096,7 @@ def test_insert_rest(transport: str = "rest", request_type=compute.InsertRouterR
     assert response.error == compute.Error(errors=[compute.Errors(code="code_value")])
     assert response.http_error_message == "http_error_message_value"
     assert response.http_error_status_code == 2374
-    assert response.id == "id_value"
+    assert response.id == 205
     assert response.insert_time == "insert_time_value"
     assert response.kind == "kind_value"
     assert response.name == "name_value"
@@ -1084,7 +1108,7 @@ def test_insert_rest(transport: str = "rest", request_type=compute.InsertRouterR
     assert response.start_time == "start_time_value"
     assert response.status == compute.Operation.Status.DONE
     assert response.status_message == "status_message_value"
-    assert response.target_id == "target_id_value"
+    assert response.target_id == 947
     assert response.target_link == "target_link_value"
     assert response.user == "user_value"
     assert response.warnings == [
@@ -1128,13 +1152,14 @@ def test_insert_rest_flattened():
         assert len(req.mock_calls) == 1
         _, http_call, http_params = req.mock_calls[0]
         body = http_params.get("data")
-        assert "project_value" in http_call[1] + str(body)
-        assert "region_value" in http_call[1] + str(body)
+        params = http_params.get("params")
+        assert "project_value" in http_call[1] + str(body) + str(params)
+        assert "region_value" in http_call[1] + str(body) + str(params)
         assert compute.Router.to_json(
             router_resource,
             including_default_value_fields=False,
             use_integers_for_enums=False,
-        ) in http_call[1] + str(body)
+        ) in http_call[1] + str(body) + str(params)
 
 
 def test_insert_rest_flattened_error():
@@ -1234,8 +1259,9 @@ def test_list_rest_flattened():
         assert len(req.mock_calls) == 1
         _, http_call, http_params = req.mock_calls[0]
         body = http_params.get("data")
-        assert "project_value" in http_call[1] + str(body)
-        assert "region_value" in http_call[1] + str(body)
+        params = http_params.get("params")
+        assert "project_value" in http_call[1] + str(body) + str(params)
+        assert "region_value" in http_call[1] + str(body) + str(params)
 
 
 def test_list_rest_flattened_error():
@@ -1311,7 +1337,7 @@ def test_patch_rest(transport: str = "rest", request_type=compute.PatchRouterReq
             error=compute.Error(errors=[compute.Errors(code="code_value")]),
             http_error_message="http_error_message_value",
             http_error_status_code=2374,
-            id="id_value",
+            id=205,
             insert_time="insert_time_value",
             kind="kind_value",
             name="name_value",
@@ -1323,7 +1349,7 @@ def test_patch_rest(transport: str = "rest", request_type=compute.PatchRouterReq
             start_time="start_time_value",
             status=compute.Operation.Status.DONE,
             status_message="status_message_value",
-            target_id="target_id_value",
+            target_id=947,
             target_link="target_link_value",
             user="user_value",
             warnings=[compute.Warnings(code=compute.Warnings.Code.CLEANUP_FAILED)],
@@ -1347,7 +1373,7 @@ def test_patch_rest(transport: str = "rest", request_type=compute.PatchRouterReq
     assert response.error == compute.Error(errors=[compute.Errors(code="code_value")])
     assert response.http_error_message == "http_error_message_value"
     assert response.http_error_status_code == 2374
-    assert response.id == "id_value"
+    assert response.id == 205
     assert response.insert_time == "insert_time_value"
     assert response.kind == "kind_value"
     assert response.name == "name_value"
@@ -1359,7 +1385,7 @@ def test_patch_rest(transport: str = "rest", request_type=compute.PatchRouterReq
     assert response.start_time == "start_time_value"
     assert response.status == compute.Operation.Status.DONE
     assert response.status_message == "status_message_value"
-    assert response.target_id == "target_id_value"
+    assert response.target_id == 947
     assert response.target_link == "target_link_value"
     assert response.user == "user_value"
     assert response.warnings == [
@@ -1404,14 +1430,15 @@ def test_patch_rest_flattened():
         assert len(req.mock_calls) == 1
         _, http_call, http_params = req.mock_calls[0]
         body = http_params.get("data")
-        assert "project_value" in http_call[1] + str(body)
-        assert "region_value" in http_call[1] + str(body)
-        assert "router_value" in http_call[1] + str(body)
+        params = http_params.get("params")
+        assert "project_value" in http_call[1] + str(body) + str(params)
+        assert "region_value" in http_call[1] + str(body) + str(params)
+        assert "router_value" in http_call[1] + str(body) + str(params)
         assert compute.Router.to_json(
             router_resource,
             including_default_value_fields=False,
             use_integers_for_enums=False,
-        ) in http_call[1] + str(body)
+        ) in http_call[1] + str(body) + str(params)
 
 
 def test_patch_rest_flattened_error():
@@ -1506,14 +1533,15 @@ def test_preview_rest_flattened():
         assert len(req.mock_calls) == 1
         _, http_call, http_params = req.mock_calls[0]
         body = http_params.get("data")
-        assert "project_value" in http_call[1] + str(body)
-        assert "region_value" in http_call[1] + str(body)
-        assert "router_value" in http_call[1] + str(body)
+        params = http_params.get("params")
+        assert "project_value" in http_call[1] + str(body) + str(params)
+        assert "region_value" in http_call[1] + str(body) + str(params)
+        assert "router_value" in http_call[1] + str(body) + str(params)
         assert compute.Router.to_json(
             router_resource,
             including_default_value_fields=False,
             use_integers_for_enums=False,
-        ) in http_call[1] + str(body)
+        ) in http_call[1] + str(body) + str(params)
 
 
 def test_preview_rest_flattened_error():
@@ -1555,7 +1583,7 @@ def test_update_rest(transport: str = "rest", request_type=compute.UpdateRouterR
             error=compute.Error(errors=[compute.Errors(code="code_value")]),
             http_error_message="http_error_message_value",
             http_error_status_code=2374,
-            id="id_value",
+            id=205,
             insert_time="insert_time_value",
             kind="kind_value",
             name="name_value",
@@ -1567,7 +1595,7 @@ def test_update_rest(transport: str = "rest", request_type=compute.UpdateRouterR
             start_time="start_time_value",
             status=compute.Operation.Status.DONE,
             status_message="status_message_value",
-            target_id="target_id_value",
+            target_id=947,
             target_link="target_link_value",
             user="user_value",
             warnings=[compute.Warnings(code=compute.Warnings.Code.CLEANUP_FAILED)],
@@ -1591,7 +1619,7 @@ def test_update_rest(transport: str = "rest", request_type=compute.UpdateRouterR
     assert response.error == compute.Error(errors=[compute.Errors(code="code_value")])
     assert response.http_error_message == "http_error_message_value"
     assert response.http_error_status_code == 2374
-    assert response.id == "id_value"
+    assert response.id == 205
     assert response.insert_time == "insert_time_value"
     assert response.kind == "kind_value"
     assert response.name == "name_value"
@@ -1603,7 +1631,7 @@ def test_update_rest(transport: str = "rest", request_type=compute.UpdateRouterR
     assert response.start_time == "start_time_value"
     assert response.status == compute.Operation.Status.DONE
     assert response.status_message == "status_message_value"
-    assert response.target_id == "target_id_value"
+    assert response.target_id == 947
     assert response.target_link == "target_link_value"
     assert response.user == "user_value"
     assert response.warnings == [
@@ -1648,14 +1676,15 @@ def test_update_rest_flattened():
         assert len(req.mock_calls) == 1
         _, http_call, http_params = req.mock_calls[0]
         body = http_params.get("data")
-        assert "project_value" in http_call[1] + str(body)
-        assert "region_value" in http_call[1] + str(body)
-        assert "router_value" in http_call[1] + str(body)
+        params = http_params.get("params")
+        assert "project_value" in http_call[1] + str(body) + str(params)
+        assert "region_value" in http_call[1] + str(body) + str(params)
+        assert "router_value" in http_call[1] + str(body) + str(params)
         assert compute.Router.to_json(
             router_resource,
             including_default_value_fields=False,
             use_integers_for_enums=False,
-        ) in http_call[1] + str(body)
+        ) in http_call[1] + str(body) + str(params)
 
 
 def test_update_rest_flattened_error():
